Learn R Programming

visdat (version 0.6.1)

vis_histogram: Visualise histogram of numeric columns in a data.frame

Description

vis_histogram visualises the distribution of every numeric column in a dataframe and displays it using a faceted ggplot object.

Usage

vis_histogram(x, ...)

Value

ggplot2 object displaying the guess of the type of values in the data frame and the position of any missing values.

Arguments

x

a data.frame

...

Other arguments are passed as geom_histogram arguments.

Examples

Run this code

vis_histogram(airquality, bins = 30)

Run the code above in your browser using DataLab