Learn R Programming

visdat (version 0.0.4.9999)

vis_dat_ly: Produces an interactive visualisation of a data.frame to tell you what it contains.

Description

vis_dat_ly uses plotly to provide an interactive version of vis_dat, providing an at-a-glance plotly object of what is inside a dataframe. Cells are coloured according to what class they are and whether the values are missing.

Usage

vis_dat_ly(x)

Arguments

x
a data.frame

Value

a plotly object

Examples

Run this code

## Not run: 
# # currently does not work, some problems with palletes and other weird messages.
# vis_dat_ly(airquality)
# 
# ## End(Not run)


Run the code above in your browser using DataLab