powered by
vis_histogram visualises the distribution of every numeric column in a dataframe and displays it using a faceted ggplot object.
vis_histogram
vis_histogram(x, ...)
ggplot2 object displaying the guess of the type of values in the data frame and the position of any missing values.
ggplot2
a data.frame
Other arguments are passed as geom_histogram arguments.
vis_histogram(airquality, bins = 30)
Run the code above in your browser using DataLab